@@ -52,6 +52,7 @@ class History;
 class IncidenceChanger;
 class CalendarClipboard;
 class TodoPurger;
+class CalFilterPartStatusProxyModel;
 }
 
 class QSplitter;
@@ -685,7 +686,7 @@ private:
      * If mimeType is set, the collection to return will have to support that mime type.
      * If no valid collection is found, an invalid one is returned.
      */
-    Akonadi::Collection defaultCollection(const QLatin1String &mimeType = QLatin1String("")) const;
+    Akonadi::Collection defaultCollection(const QLatin1StringView &mimeType = QLatin1StringView("")) const;
 
     /**
      * Creates a new incidence editor and chooses a decent default for the collection
@@ -693,6 +694,11 @@ private:
      */
     IncidenceEditorNG::IncidenceDialog *createIncidenceEditor(const Akonadi::Item &item, const Akonadi::Collection &collection = Akonadi::Collection());
 
+    /**
+     * Returns the model that contains events, with any proxy filters on top.
+     */
+    QAbstractItemModel *eventsModel() const;
+
     /**
      * Loops over mCalendars and invokes @p func for each valid calendar in the list.
      *
@@ -738,6 +744,8 @@ private:
     QList<KCalendarCore::CalFilter *> mFilters;
     KCalendarCore::CalFilter *mCurrentFilter = nullptr;
 
+    Akonadi::CalFilterPartStatusProxyModel *mPartStatFilterProxy = nullptr;
+
     // various housekeeping variables.
     bool mReadOnly; // flag indicating if calendar is read-only
 
