@@ -225,7 +225,7 @@ void KODayMatrix::updateView(QDate actdate)
         if (!holidays.isEmpty()) {
             holiStr = holidays.join(i18nc("delimiter for joining holiday names", ","));
             if (holiStr.isEmpty()) {
-                holiStr = QLatin1String("");
+                holiStr = QLatin1StringView("");
             }
         }
         mHolidays[i] = holiStr;
